"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decorateGetDefinition = void 0;
const utils_1 = require("../utils");
function decorateGetDefinition(ls, snapshotManager, logger) {
    const getDefinitionAndBoundSpan = ls.getDefinitionAndBoundSpan;
    ls.getDefinitionAndBoundSpan = (fileName, position) => {
        const definition = getDefinitionAndBoundSpan(fileName, position);
        if (!(definition === null || definition === void 0 ? void 0 : definition.definitions)) {
            return definition;
        }
        return {
            ...definition,
            definitions: definition.definitions
                .map((def) => {
                var _a;
                if (!utils_1.isSvelteFilePath(def.fileName)) {
                    return def;
                }
                const textSpan = (_a = snapshotManager
                    .get(def.fileName)) === null || _a === void 0 ? void 0 : _a.getOriginalTextSpan(def.textSpan);
                if (!textSpan) {
                    return undefined;
                }
                return {
                    ...def,
                    textSpan,
                    // Spare the work for now
                    originalTextSpan: undefined,
                    contextSpan: undefined,
                    originalContextSpan: undefined
                };
            })
                .filter(utils_1.isNotNullOrUndefined)
        };
    };
}
exports.decorateGetDefinition = decorateGetDefinition;
