"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decorateLanguageService = void 0;
const utils_1 = require("../utils");
const completions_1 = require("./completions");
const definition_1 = require("./definition");
const diagnostics_1 = require("./diagnostics");
const find_references_1 = require("./find-references");
const implementation_1 = require("./implementation");
const rename_1 = require("./rename");
function decorateLanguageService(ls, snapshotManager, logger) {
    patchLineColumnOffset(ls, snapshotManager);
    rename_1.decorateRename(ls, snapshotManager, logger);
    diagnostics_1.decorateDiagnostics(ls, logger);
    find_references_1.decorateFindReferences(ls, snapshotManager, logger);
    completions_1.decorateCompletions(ls, logger);
    definition_1.decorateGetDefinition(ls, snapshotManager, logger);
    implementation_1.decorateGetImplementation(ls, snapshotManager, logger);
    return ls;
}
exports.decorateLanguageService = decorateLanguageService;
function patchLineColumnOffset(ls, snapshotManager) {
    if (!ls.toLineColumnOffset) {
        return;
    }
    // We need to patch this because (according to source, only) getDefinition uses this
    const toLineColumnOffset = ls.toLineColumnOffset;
    ls.toLineColumnOffset = (fileName, position) => {
        if (utils_1.isSvelteFilePath(fileName)) {
            const snapshot = snapshotManager.get(fileName);
            if (snapshot) {
                return snapshot.positionAt(position);
            }
        }
        return toLineColumnOffset(fileName, position);
    };
}
